======================================================================
``psyclone.domain.nemo.transformations.nemo_allarrayrange2loop_trans``
======================================================================

.. automodule:: psyclone.domain.nemo.transformations.nemo_allarrayrange2loop_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.transformations.nemo_allarrayrange2loop_trans


Classes
=======

- :py:class:`NemoAllArrayRange2LoopTrans`:
  Provides a transformation for all PSyIR Array Ranges in an


.. autoclass:: NemoAllArrayRange2LoopTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: NemoAllArrayRange2LoopTrans
      :parts: 1
